Re: [RFC PATCH 00/11] rebase -i run without forking rebase--interactive
- From
Ævar Arnfjörð Bjarmason <avarab@gmail.com>
- Date
- Mar 20, 2019, 23:05 UTC
- Message-ID
- <87y359cfjj.fsf@evledraar.gmail.com>
- In-Reply-To
- <20190319190317.6632-1-phillip.wood123@gmail.com>
On Tue, Mar 19 2019, Phillip Wood wrote:
Show 17 quoted lines
> From: Phillip Wood <phillip.wood@dunelm.org.uk>
>
> When the builtin rebase starts an interactive rebase it parses the
> options and then repackages them and forks `rebase--interactive`. This
> series refactors rebase--interactive so that interactive rebases can
> be started by the builtin rebase without forking. My motivation was to
> make it easier to debug the sequencer but this should help future
> maintainability.
>
> This series involves some code movement so viewing the diffs with
> --color-moved is recommended.
>
> These patches are based on a merge of master [e902e9bcae ("The second
> batch", 2019-03-11)] and ag/sequencer-reduce-rewriting-todo ed35d18841
> ("rebase--interactive: move transform_todo_file()", 2019-03-05). They
> can be fetched from the tag rebase-i-no-fork/rfc at
> https://github.com/phillipwood/git.gitJust a that the t/perf/*rebase* numbers look much better with this. I don't have these in front of me anymore, but over 10 runs with -O3 one of those long-runnings test was 30% faster.
Another one (rebase -i) went from 0.02 to 0.01 sec, with that short amount of time I wonder (but didn't dig) if the test itself is broken...